@@ -673,6 +673,10 @@ class _Formatter(logging.Formatter):
             s = "%s.%03d" % (t, record.msecs)
         return s
 
+    def formatMessage(self, record: logging.LogRecord) -> str:
+        record.__dict__.setdefault("func_prefix", "Unknown")
+        return super().formatMessage(record)
+
 
 class LoggingMixin:
     """
@@ -1041,7 +1045,10 @@ class PureLoggingMixin:
             logger.log(
                 msg_level,
                 msg,
-                extra={"func_prefix": LoggingMixin._get_func_prefix(frame)},
+                extra={
+                    "custom_prefix": "",
+                    "func_prefix": LoggingMixin._get_func_prefix(frame),
+                },
             )
         return logger
 
@@ -1057,7 +1064,11 @@ class PureLoggingMixin:
             clear_stuffs_after_exc=False,
         ):
             logger.exception(
-                msg, extra={"func_prefix": LoggingMixin._get_func_prefix(frame)}
+                msg,
+                extra={
+                    "custom_prefix": LoggingMixin.error_prefix,
+                    "func_prefix": LoggingMixin._get_func_prefix(frame),
+                }
             )
 
     def del_logger(self, name):
